// source: dashboard.proto
/**
 * @fileoverview
 * @enhanceable
 * @suppress {missingRequire} reports error on implicit type usages.
 * @suppress {messageConventions} JS Compiler reports an error if a variable or
 *     field starts with 'MSG_' and isn't a translatable message.
 * @public
 */
// GENERATED CODE -- DO NOT EDIT!
/* eslint-disable */
// @ts-nocheck

var jspb = require('google-protobuf');
var goog = jspb;
var global =
    (typeof globalThis !== 'undefined' && globalThis) ||
    (typeof window !== 'undefined' && window) ||
    (typeof global !== 'undefined' && global) ||
    (typeof self !== 'undefined' && self) ||
    (function () { return this; }).call(null) ||
    Function('return this')();

var annotations_pb = require('./annotations_pb.js');
goog.object.extend(proto, annotations_pb);
var account_pb = require('./account_pb.js');
goog.object.extend(proto, account_pb);
var discussions_pb = require('./discussions_pb.js');
goog.object.extend(proto, discussions_pb);
var events_pb = require('./events_pb.js');
goog.object.extend(proto, events_pb);
var requests_pb = require('./requests_pb.js');
goog.object.extend(proto, requests_pb);
goog.exportSymbol('proto.org.couchers.api.dashboard.GetDashboardV2Req', null, global);
goog.exportSymbol('proto.org.couchers.api.dashboard.GetDashboardV2Res', null, global);
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.dashboard.GetDashboardV2Req = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.dashboard.GetDashboardV2Req, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.dashboard.GetDashboardV2Req.displayName = 'proto.org.couchers.api.dashboard.GetDashboardV2Req';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.dashboard.GetDashboardV2Res, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.dashboard.GetDashboardV2Res.displayName = 'proto.org.couchers.api.dashboard.GetDashboardV2Res';
}



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Req.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.dashboard.GetDashboardV2Req.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.dashboard.GetDashboardV2Req} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.dashboard.GetDashboardV2Req.toObject = function(includeInstance, msg) {
  var f, obj = {

  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Req}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Req.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.dashboard.GetDashboardV2Req;
  return proto.org.couchers.api.dashboard.GetDashboardV2Req.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.dashboard.GetDashboardV2Req} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Req}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Req.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Req.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.dashboard.GetDashboardV2Req.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.dashboard.GetDashboardV2Req} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.dashboard.GetDashboardV2Req.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.dashboard.GetDashboardV2Res.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.dashboard.GetDashboardV2Res} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.toObject = function(includeInstance, msg) {
  var f, obj = {
    reminders: (f = msg.getReminders()) && account_pb.GetRemindersRes.toObject(includeInstance, f),
    surfing: (f = msg.getSurfing()) && requests_pb.ListHostRequestsRes.toObject(includeInstance, f),
    hosting: (f = msg.getHosting()) && requests_pb.ListHostRequestsRes.toObject(includeInstance, f),
    myEvents: (f = msg.getMyEvents()) && events_pb.ListMyEventsRes.toObject(includeInstance, f),
    communityEvents: (f = msg.getCommunityEvents()) && events_pb.ListMyEventsRes.toObject(includeInstance, f),
    discussions: (f = msg.getDiscussions()) && discussions_pb.ListMyCommunitiesDiscussionsRes.toObject(includeInstance, f)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.dashboard.GetDashboardV2Res;
  return proto.org.couchers.api.dashboard.GetDashboardV2Res.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.dashboard.GetDashboardV2Res} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new account_pb.GetRemindersRes;
      reader.readMessage(value,account_pb.GetRemindersRes.deserializeBinaryFromReader);
      msg.setReminders(value);
      break;
    case 2:
      var value = new requests_pb.ListHostRequestsRes;
      reader.readMessage(value,requests_pb.ListHostRequestsRes.deserializeBinaryFromReader);
      msg.setSurfing(value);
      break;
    case 3:
      var value = new requests_pb.ListHostRequestsRes;
      reader.readMessage(value,requests_pb.ListHostRequestsRes.deserializeBinaryFromReader);
      msg.setHosting(value);
      break;
    case 4:
      var value = new events_pb.ListMyEventsRes;
      reader.readMessage(value,events_pb.ListMyEventsRes.deserializeBinaryFromReader);
      msg.setMyEvents(value);
      break;
    case 5:
      var value = new events_pb.ListMyEventsRes;
      reader.readMessage(value,events_pb.ListMyEventsRes.deserializeBinaryFromReader);
      msg.setCommunityEvents(value);
      break;
    case 6:
      var value = new discussions_pb.ListMyCommunitiesDiscussionsRes;
      reader.readMessage(value,discussions_pb.ListMyCommunitiesDiscussionsRes.deserializeBinaryFromReader);
      msg.setDiscussions(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.dashboard.GetDashboardV2Res.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.dashboard.GetDashboardV2Res} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getReminders();
  if (f != null) {
    writer.writeMessage(
      1,
      f,
      account_pb.GetRemindersRes.serializeBinaryToWriter
    );
  }
  f = message.getSurfing();
  if (f != null) {
    writer.writeMessage(
      2,
      f,
      requests_pb.ListHostRequestsRes.serializeBinaryToWriter
    );
  }
  f = message.getHosting();
  if (f != null) {
    writer.writeMessage(
      3,
      f,
      requests_pb.ListHostRequestsRes.serializeBinaryToWriter
    );
  }
  f = message.getMyEvents();
  if (f != null) {
    writer.writeMessage(
      4,
      f,
      events_pb.ListMyEventsRes.serializeBinaryToWriter
    );
  }
  f = message.getCommunityEvents();
  if (f != null) {
    writer.writeMessage(
      5,
      f,
      events_pb.ListMyEventsRes.serializeBinaryToWriter
    );
  }
  f = message.getDiscussions();
  if (f != null) {
    writer.writeMessage(
      6,
      f,
      discussions_pb.ListMyCommunitiesDiscussionsRes.serializeBinaryToWriter
    );
  }
};


/**
 * optional org.couchers.api.account.GetRemindersRes reminders = 1;
 * @return {?proto.org.couchers.api.account.GetRemindersRes}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.getReminders = function() {
  return /** @type{?proto.org.couchers.api.account.GetRemindersRes} */ (
    jspb.Message.getWrapperField(this, account_pb.GetRemindersRes, 1));
};


/**
 * @param {?proto.org.couchers.api.account.GetRemindersRes|undefined} value
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
*/
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.setReminders = function(value) {
  return jspb.Message.setWrapperField(this, 1, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.clearReminders = function() {
  return this.setReminders(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.hasReminders = function() {
  return jspb.Message.getField(this, 1) != null;
};


/**
 * optional org.couchers.api.requests.ListHostRequestsRes surfing = 2;
 * @return {?proto.org.couchers.api.requests.ListHostRequestsRes}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.getSurfing = function() {
  return /** @type{?proto.org.couchers.api.requests.ListHostRequestsRes} */ (
    jspb.Message.getWrapperField(this, requests_pb.ListHostRequestsRes, 2));
};


/**
 * @param {?proto.org.couchers.api.requests.ListHostRequestsRes|undefined} value
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
*/
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.setSurfing = function(value) {
  return jspb.Message.setWrapperField(this, 2, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.clearSurfing = function() {
  return this.setSurfing(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.hasSurfing = function() {
  return jspb.Message.getField(this, 2) != null;
};


/**
 * optional org.couchers.api.requests.ListHostRequestsRes hosting = 3;
 * @return {?proto.org.couchers.api.requests.ListHostRequestsRes}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.getHosting = function() {
  return /** @type{?proto.org.couchers.api.requests.ListHostRequestsRes} */ (
    jspb.Message.getWrapperField(this, requests_pb.ListHostRequestsRes, 3));
};


/**
 * @param {?proto.org.couchers.api.requests.ListHostRequestsRes|undefined} value
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
*/
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.setHosting = function(value) {
  return jspb.Message.setWrapperField(this, 3, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.clearHosting = function() {
  return this.setHosting(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.hasHosting = function() {
  return jspb.Message.getField(this, 3) != null;
};


/**
 * optional org.couchers.api.events.ListMyEventsRes my_events = 4;
 * @return {?proto.org.couchers.api.events.ListMyEventsRes}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.getMyEvents = function() {
  return /** @type{?proto.org.couchers.api.events.ListMyEventsRes} */ (
    jspb.Message.getWrapperField(this, events_pb.ListMyEventsRes, 4));
};


/**
 * @param {?proto.org.couchers.api.events.ListMyEventsRes|undefined} value
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
*/
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.setMyEvents = function(value) {
  return jspb.Message.setWrapperField(this, 4, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.clearMyEvents = function() {
  return this.setMyEvents(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.hasMyEvents = function() {
  return jspb.Message.getField(this, 4) != null;
};


/**
 * optional org.couchers.api.events.ListMyEventsRes community_events = 5;
 * @return {?proto.org.couchers.api.events.ListMyEventsRes}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.getCommunityEvents = function() {
  return /** @type{?proto.org.couchers.api.events.ListMyEventsRes} */ (
    jspb.Message.getWrapperField(this, events_pb.ListMyEventsRes, 5));
};


/**
 * @param {?proto.org.couchers.api.events.ListMyEventsRes|undefined} value
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
*/
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.setCommunityEvents = function(value) {
  return jspb.Message.setWrapperField(this, 5, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.clearCommunityEvents = function() {
  return this.setCommunityEvents(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.hasCommunityEvents = function() {
  return jspb.Message.getField(this, 5) != null;
};


/**
 * optional org.couchers.api.discussions.ListMyCommunitiesDiscussionsRes discussions = 6;
 * @return {?proto.org.couchers.api.discussions.ListMyCommunitiesDiscussionsRes}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.getDiscussions = function() {
  return /** @type{?proto.org.couchers.api.discussions.ListMyCommunitiesDiscussionsRes} */ (
    jspb.Message.getWrapperField(this, discussions_pb.ListMyCommunitiesDiscussionsRes, 6));
};


/**
 * @param {?proto.org.couchers.api.discussions.ListMyCommunitiesDiscussionsRes|undefined} value
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
*/
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.setDiscussions = function(value) {
  return jspb.Message.setWrapperField(this, 6, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.dashboard.GetDashboardV2Res} returns this
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.clearDiscussions = function() {
  return this.setDiscussions(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.dashboard.GetDashboardV2Res.prototype.hasDiscussions = function() {
  return jspb.Message.getField(this, 6) != null;
};


goog.object.extend(exports, proto.org.couchers.api.dashboard);
