import * as jspb from 'google-protobuf'

import * as annotations_pb from './annotations_pb'; // proto import: "annotations.proto"
import * as account_pb from './account_pb'; // proto import: "account.proto"
import * as discussions_pb from './discussions_pb'; // proto import: "discussions.proto"
import * as events_pb from './events_pb'; // proto import: "events.proto"
import * as requests_pb from './requests_pb'; // proto import: "requests.proto"


export class GetDashboardV2Req extends jspb.Message {
  serializeBinary(): Uint8Array;
  toObject(includeInstance?: boolean): GetDashboardV2Req.AsObject;
  static toObject(includeInstance: boolean, msg: GetDashboardV2Req): GetDashboardV2Req.AsObject;
  static serializeBinaryToWriter(message: GetDashboardV2Req, writer: jspb.BinaryWriter): void;
  static deserializeBinary(bytes: Uint8Array): GetDashboardV2Req;
  static deserializeBinaryFromReader(message: GetDashboardV2Req, reader: jspb.BinaryReader): GetDashboardV2Req;
}

export namespace GetDashboardV2Req {
  export type AsObject = {
  }
}

export class GetDashboardV2Res extends jspb.Message {
  getReminders(): account_pb.GetRemindersRes | undefined;
  setReminders(value?: account_pb.GetRemindersRes): GetDashboardV2Res;
  hasReminders(): boolean;
  clearReminders(): GetDashboardV2Res;

  getSurfing(): requests_pb.ListHostRequestsRes | undefined;
  setSurfing(value?: requests_pb.ListHostRequestsRes): GetDashboardV2Res;
  hasSurfing(): boolean;
  clearSurfing(): GetDashboardV2Res;

  getHosting(): requests_pb.ListHostRequestsRes | undefined;
  setHosting(value?: requests_pb.ListHostRequestsRes): GetDashboardV2Res;
  hasHosting(): boolean;
  clearHosting(): GetDashboardV2Res;

  getMyEvents(): events_pb.ListMyEventsRes | undefined;
  setMyEvents(value?: events_pb.ListMyEventsRes): GetDashboardV2Res;
  hasMyEvents(): boolean;
  clearMyEvents(): GetDashboardV2Res;

  getCommunityEvents(): events_pb.ListMyEventsRes | undefined;
  setCommunityEvents(value?: events_pb.ListMyEventsRes): GetDashboardV2Res;
  hasCommunityEvents(): boolean;
  clearCommunityEvents(): GetDashboardV2Res;

  getDiscussions(): discussions_pb.ListMyCommunitiesDiscussionsRes | undefined;
  setDiscussions(value?: discussions_pb.ListMyCommunitiesDiscussionsRes): GetDashboardV2Res;
  hasDiscussions(): boolean;
  clearDiscussions(): GetDashboardV2Res;

  serializeBinary(): Uint8Array;
  toObject(includeInstance?: boolean): GetDashboardV2Res.AsObject;
  static toObject(includeInstance: boolean, msg: GetDashboardV2Res): GetDashboardV2Res.AsObject;
  static serializeBinaryToWriter(message: GetDashboardV2Res, writer: jspb.BinaryWriter): void;
  static deserializeBinary(bytes: Uint8Array): GetDashboardV2Res;
  static deserializeBinaryFromReader(message: GetDashboardV2Res, reader: jspb.BinaryReader): GetDashboardV2Res;
}

export namespace GetDashboardV2Res {
  export type AsObject = {
    reminders?: account_pb.GetRemindersRes.AsObject,
    surfing?: requests_pb.ListHostRequestsRes.AsObject,
    hosting?: requests_pb.ListHostRequestsRes.AsObject,
    myEvents?: events_pb.ListMyEventsRes.AsObject,
    communityEvents?: events_pb.ListMyEventsRes.AsObject,
    discussions?: discussions_pb.ListMyCommunitiesDiscussionsRes.AsObject,
  }
}

