/**
 * @fileoverview gRPC-Web generated client stub for org.couchers.api.postal_verification
 * @enhanceable
 * @public
 */

// Code generated by protoc-gen-grpc-web. DO NOT EDIT.
// versions:
// 	protoc-gen-grpc-web v1.5.0
// 	protoc              v5.26.1
// source: postal_verification.proto


/* eslint-disable */
// @ts-nocheck



const grpc = {};
grpc.web = require('grpc-web');


var google_protobuf_empty_pb = require('google-protobuf/google/protobuf/empty_pb.js')

var google_protobuf_timestamp_pb = require('google-protobuf/google/protobuf/timestamp_pb.js')

var annotations_pb = require('./annotations_pb.js')
const proto = {};
proto.org = {};
proto.org.couchers = {};
proto.org.couchers.api = {};
proto.org.couchers.api.postal_verification = require('./postal_verification_pb.js');

/**
 * @param {string} hostname
 * @param {?Object} credentials
 * @param {?grpc.web.ClientOptions} options
 * @constructor
 * @struct
 * @final
 */
proto.org.couchers.api.postal_verification.PostalVerificationClient =
    function(hostname, credentials, options) {
  if (!options) options = {};
  options.format = 'binary';

  /**
   * @private @const {!grpc.web.GrpcWebClientBase} The client
   */
  this.client_ = new grpc.web.GrpcWebClientBase(options);

  /**
   * @private @const {string} The hostname
   */
  this.hostname_ = hostname.replace(/\/+$/, '');

};


/**
 * @param {string} hostname
 * @param {?Object} credentials
 * @param {?grpc.web.ClientOptions} options
 * @constructor
 * @struct
 * @final
 */
proto.org.couchers.api.postal_verification.PostalVerificationPromiseClient =
    function(hostname, credentials, options) {
  if (!options) options = {};
  options.format = 'binary';

  /**
   * @private @const {!grpc.web.GrpcWebClientBase} The client
   */
  this.client_ = new grpc.web.GrpcWebClientBase(options);

  /**
   * @private @const {string} The hostname
   */
  this.hostname_ = hostname.replace(/\/+$/, '');

};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq,
 *   !proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes>}
 */
const methodDescriptor_PostalVerification_InitiatePostalVerification = new grpc.web.MethodDescriptor(
  '/org.couchers.api.postal_verification.PostalVerification/InitiatePostalVerification',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq,
  proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes,
  /**
   * @param {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.api.postal_verification.PostalVerificationClient.prototype.initiatePostalVerification =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/InitiatePostalVerification',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_InitiatePostalVerification,
      callback);
};


/**
 * @param {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.api.postal_verification.PostalVerificationPromiseClient.prototype.initiatePostalVerification =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/InitiatePostalVerification',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_InitiatePostalVerification);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq,
 *   !proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes>}
 */
const methodDescriptor_PostalVerification_ConfirmPostalAddress = new grpc.web.MethodDescriptor(
  '/org.couchers.api.postal_verification.PostalVerification/ConfirmPostalAddress',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq,
  proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes,
  /**
   * @param {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.api.postal_verification.PostalVerificationClient.prototype.confirmPostalAddress =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/ConfirmPostalAddress',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_ConfirmPostalAddress,
      callback);
};


/**
 * @param {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.api.postal_verification.PostalVerificationPromiseClient.prototype.confirmPostalAddress =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/ConfirmPostalAddress',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_ConfirmPostalAddress);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq,
 *   !proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes>}
 */
const methodDescriptor_PostalVerification_GetPostalVerificationStatus = new grpc.web.MethodDescriptor(
  '/org.couchers.api.postal_verification.PostalVerification/GetPostalVerificationStatus',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq,
  proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes,
  /**
   * @param {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.api.postal_verification.PostalVerificationClient.prototype.getPostalVerificationStatus =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/GetPostalVerificationStatus',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_GetPostalVerificationStatus,
      callback);
};


/**
 * @param {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.api.postal_verification.PostalVerificationPromiseClient.prototype.getPostalVerificationStatus =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/GetPostalVerificationStatus',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_GetPostalVerificationStatus);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.api.postal_verification.VerifyPostalCodeReq,
 *   !proto.org.couchers.api.postal_verification.VerifyPostalCodeRes>}
 */
const methodDescriptor_PostalVerification_VerifyPostalCode = new grpc.web.MethodDescriptor(
  '/org.couchers.api.postal_verification.PostalVerification/VerifyPostalCode',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.api.postal_verification.VerifyPostalCodeReq,
  proto.org.couchers.api.postal_verification.VerifyPostalCodeRes,
  /**
   * @param {!proto.org.couchers.api.postal_verification.VerifyPostalCodeReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.api.postal_verification.VerifyPostalCodeReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.api.postal_verification.VerifyPostalCodeRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.api.postal_verification.VerifyPostalCodeRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.api.postal_verification.PostalVerificationClient.prototype.verifyPostalCode =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/VerifyPostalCode',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_VerifyPostalCode,
      callback);
};


/**
 * @param {!proto.org.couchers.api.postal_verification.VerifyPostalCodeReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.api.postal_verification.VerifyPostalCodeRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.api.postal_verification.PostalVerificationPromiseClient.prototype.verifyPostalCode =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/VerifyPostalCode',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_VerifyPostalCode);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.api.postal_verification.CancelPostalVerificationReq,
 *   !proto.google.protobuf.Empty>}
 */
const methodDescriptor_PostalVerification_CancelPostalVerification = new grpc.web.MethodDescriptor(
  '/org.couchers.api.postal_verification.PostalVerification/CancelPostalVerification',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.api.postal_verification.CancelPostalVerificationReq,
  google_protobuf_empty_pb.Empty,
  /**
   * @param {!proto.org.couchers.api.postal_verification.CancelPostalVerificationReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  google_protobuf_empty_pb.Empty.deserializeBinary
);


/**
 * @param {!proto.org.couchers.api.postal_verification.CancelPostalVerificationReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.google.protobuf.Empty)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.google.protobuf.Empty>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.api.postal_verification.PostalVerificationClient.prototype.cancelPostalVerification =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/CancelPostalVerification',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_CancelPostalVerification,
      callback);
};


/**
 * @param {!proto.org.couchers.api.postal_verification.CancelPostalVerificationReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.google.protobuf.Empty>}
 *     Promise that resolves to the response
 */
proto.org.couchers.api.postal_verification.PostalVerificationPromiseClient.prototype.cancelPostalVerification =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/CancelPostalVerification',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_CancelPostalVerification);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq,
 *   !proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes>}
 */
const methodDescriptor_PostalVerification_ListPostalVerificationAttempts = new grpc.web.MethodDescriptor(
  '/org.couchers.api.postal_verification.PostalVerification/ListPostalVerificationAttempts',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq,
  proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes,
  /**
   * @param {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.api.postal_verification.PostalVerificationClient.prototype.listPostalVerificationAttempts =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/ListPostalVerificationAttempts',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_ListPostalVerificationAttempts,
      callback);
};


/**
 * @param {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.api.postal_verification.PostalVerificationPromiseClient.prototype.listPostalVerificationAttempts =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.api.postal_verification.PostalVerification/ListPostalVerificationAttempts',
      request,
      metadata || {},
      methodDescriptor_PostalVerification_ListPostalVerificationAttempts);
};


module.exports = proto.org.couchers.api.postal_verification;

