import * as grpcWeb from 'grpc-web';

import * as dashboard_pb from './dashboard_pb'; // proto import: "dashboard.proto"


export class DashboardClient {
  constructor (hostname: string,
               credentials?: null | { [index: string]: string; },
               options?: null | { [index: string]: any; });

  getDashboardV2(
    request: dashboard_pb.GetDashboardV2Req,
    metadata: grpcWeb.Metadata | undefined,
    callback: (err: grpcWeb.RpcError,
               response: dashboard_pb.GetDashboardV2Res) => void
  ): grpcWeb.ClientReadableStream<dashboard_pb.GetDashboardV2Res>;

}

export class DashboardPromiseClient {
  constructor (hostname: string,
               credentials?: null | { [index: string]: string; },
               options?: null | { [index: string]: any; });

  getDashboardV2(
    request: dashboard_pb.GetDashboardV2Req,
    metadata?: grpcWeb.Metadata
  ): Promise<dashboard_pb.GetDashboardV2Res>;

}

