import * as jspb from 'google-protobuf'

import * as google_api_http_pb from '../../google/api/http_pb'; // proto import: "google/api/http.proto"
import * as google_protobuf_descriptor_pb from 'google-protobuf/google/protobuf/descriptor_pb'; // proto import: "google/protobuf/descriptor.proto"


