import * as jspb from 'google-protobuf'

import * as google_protobuf_descriptor_pb from 'google-protobuf/google/protobuf/descriptor_pb'; // proto import: "google/protobuf/descriptor.proto"


export enum AuthLevel { 
  AUTH_LEVEL_UNKNOWN = 0,
  AUTH_LEVEL_OPEN = 1,
  AUTH_LEVEL_JAILED = 2,
  AUTH_LEVEL_SECURE = 3,
  AUTH_LEVEL_EDITOR = 5,
  AUTH_LEVEL_ADMIN = 4,
}
