/**
 * @fileoverview gRPC-Web generated client stub for org.couchers.editor
 * @enhanceable
 * @public
 */

// Code generated by protoc-gen-grpc-web. DO NOT EDIT.
// versions:
// 	protoc-gen-grpc-web v1.5.0
// 	protoc              v5.26.1
// source: editor.proto


/* eslint-disable */
// @ts-nocheck



const grpc = {};
grpc.web = require('grpc-web');


var google_protobuf_empty_pb = require('google-protobuf/google/protobuf/empty_pb.js')

var google_protobuf_timestamp_pb = require('google-protobuf/google/protobuf/timestamp_pb.js')

var google_protobuf_wrappers_pb = require('google-protobuf/google/protobuf/wrappers_pb.js')

var annotations_pb = require('./annotations_pb.js')

var communities_pb = require('./communities_pb.js')

var postal_verification_pb = require('./postal_verification_pb.js')
const proto = {};
proto.org = {};
proto.org.couchers = {};
proto.org.couchers.editor = require('./editor_pb.js');

/**
 * @param {string} hostname
 * @param {?Object} credentials
 * @param {?grpc.web.ClientOptions} options
 * @constructor
 * @struct
 * @final
 */
proto.org.couchers.editor.EditorClient =
    function(hostname, credentials, options) {
  if (!options) options = {};
  options.format = 'binary';

  /**
   * @private @const {!grpc.web.GrpcWebClientBase} The client
   */
  this.client_ = new grpc.web.GrpcWebClientBase(options);

  /**
   * @private @const {string} The hostname
   */
  this.hostname_ = hostname.replace(/\/+$/, '');

};


/**
 * @param {string} hostname
 * @param {?Object} credentials
 * @param {?grpc.web.ClientOptions} options
 * @constructor
 * @struct
 * @final
 */
proto.org.couchers.editor.EditorPromiseClient =
    function(hostname, credentials, options) {
  if (!options) options = {};
  options.format = 'binary';

  /**
   * @private @const {!grpc.web.GrpcWebClientBase} The client
   */
  this.client_ = new grpc.web.GrpcWebClientBase(options);

  /**
   * @private @const {string} The hostname
   */
  this.hostname_ = hostname.replace(/\/+$/, '');

};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.CreateCommunityReq,
 *   !proto.org.couchers.api.communities.Community>}
 */
const methodDescriptor_Editor_CreateCommunity = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/CreateCommunity',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.CreateCommunityReq,
  communities_pb.Community,
  /**
   * @param {!proto.org.couchers.editor.CreateCommunityReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  communities_pb.Community.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.CreateCommunityReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.api.communities.Community)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.api.communities.Community>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.createCommunity =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/CreateCommunity',
      request,
      metadata || {},
      methodDescriptor_Editor_CreateCommunity,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.CreateCommunityReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.api.communities.Community>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.createCommunity =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/CreateCommunity',
      request,
      metadata || {},
      methodDescriptor_Editor_CreateCommunity);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.UpdateCommunityReq,
 *   !proto.org.couchers.api.communities.Community>}
 */
const methodDescriptor_Editor_UpdateCommunity = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/UpdateCommunity',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.UpdateCommunityReq,
  communities_pb.Community,
  /**
   * @param {!proto.org.couchers.editor.UpdateCommunityReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  communities_pb.Community.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.UpdateCommunityReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.api.communities.Community)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.api.communities.Community>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.updateCommunity =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/UpdateCommunity',
      request,
      metadata || {},
      methodDescriptor_Editor_UpdateCommunity,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.UpdateCommunityReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.api.communities.Community>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.updateCommunity =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/UpdateCommunity',
      request,
      metadata || {},
      methodDescriptor_Editor_UpdateCommunity);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.ListEventCommunityInviteRequestsReq,
 *   !proto.org.couchers.editor.ListEventCommunityInviteRequestsRes>}
 */
const methodDescriptor_Editor_ListEventCommunityInviteRequests = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/ListEventCommunityInviteRequests',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.ListEventCommunityInviteRequestsReq,
  proto.org.couchers.editor.ListEventCommunityInviteRequestsRes,
  /**
   * @param {!proto.org.couchers.editor.ListEventCommunityInviteRequestsReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.editor.ListEventCommunityInviteRequestsRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.ListEventCommunityInviteRequestsReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.editor.ListEventCommunityInviteRequestsRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.editor.ListEventCommunityInviteRequestsRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.listEventCommunityInviteRequests =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/ListEventCommunityInviteRequests',
      request,
      metadata || {},
      methodDescriptor_Editor_ListEventCommunityInviteRequests,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.ListEventCommunityInviteRequestsReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.editor.ListEventCommunityInviteRequestsRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.listEventCommunityInviteRequests =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/ListEventCommunityInviteRequests',
      request,
      metadata || {},
      methodDescriptor_Editor_ListEventCommunityInviteRequests);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.DecideEventCommunityInviteRequestReq,
 *   !proto.org.couchers.editor.DecideEventCommunityInviteRequestRes>}
 */
const methodDescriptor_Editor_DecideEventCommunityInviteRequest = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/DecideEventCommunityInviteRequest',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.DecideEventCommunityInviteRequestReq,
  proto.org.couchers.editor.DecideEventCommunityInviteRequestRes,
  /**
   * @param {!proto.org.couchers.editor.DecideEventCommunityInviteRequestReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.editor.DecideEventCommunityInviteRequestRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.DecideEventCommunityInviteRequestReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.editor.DecideEventCommunityInviteRequestRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.editor.DecideEventCommunityInviteRequestRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.decideEventCommunityInviteRequest =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/DecideEventCommunityInviteRequest',
      request,
      metadata || {},
      methodDescriptor_Editor_DecideEventCommunityInviteRequest,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.DecideEventCommunityInviteRequestReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.editor.DecideEventCommunityInviteRequestRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.decideEventCommunityInviteRequest =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/DecideEventCommunityInviteRequest',
      request,
      metadata || {},
      methodDescriptor_Editor_DecideEventCommunityInviteRequest);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.SendBlogPostNotificationReq,
 *   !proto.google.protobuf.Empty>}
 */
const methodDescriptor_Editor_SendBlogPostNotification = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/SendBlogPostNotification',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.SendBlogPostNotificationReq,
  google_protobuf_empty_pb.Empty,
  /**
   * @param {!proto.org.couchers.editor.SendBlogPostNotificationReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  google_protobuf_empty_pb.Empty.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.SendBlogPostNotificationReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.google.protobuf.Empty)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.google.protobuf.Empty>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.sendBlogPostNotification =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/SendBlogPostNotification',
      request,
      metadata || {},
      methodDescriptor_Editor_SendBlogPostNotification,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.SendBlogPostNotificationReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.google.protobuf.Empty>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.sendBlogPostNotification =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/SendBlogPostNotification',
      request,
      metadata || {},
      methodDescriptor_Editor_SendBlogPostNotification);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.MakeUserVolunteerReq,
 *   !proto.org.couchers.editor.Volunteer>}
 */
const methodDescriptor_Editor_MakeUserVolunteer = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/MakeUserVolunteer',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.MakeUserVolunteerReq,
  proto.org.couchers.editor.Volunteer,
  /**
   * @param {!proto.org.couchers.editor.MakeUserVolunteerReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.editor.Volunteer.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.MakeUserVolunteerReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.editor.Volunteer)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.editor.Volunteer>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.makeUserVolunteer =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/MakeUserVolunteer',
      request,
      metadata || {},
      methodDescriptor_Editor_MakeUserVolunteer,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.MakeUserVolunteerReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.editor.Volunteer>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.makeUserVolunteer =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/MakeUserVolunteer',
      request,
      metadata || {},
      methodDescriptor_Editor_MakeUserVolunteer);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.UpdateVolunteerReq,
 *   !proto.org.couchers.editor.Volunteer>}
 */
const methodDescriptor_Editor_UpdateVolunteer = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/UpdateVolunteer',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.UpdateVolunteerReq,
  proto.org.couchers.editor.Volunteer,
  /**
   * @param {!proto.org.couchers.editor.UpdateVolunteerReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.editor.Volunteer.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.UpdateVolunteerReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.editor.Volunteer)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.editor.Volunteer>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.updateVolunteer =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/UpdateVolunteer',
      request,
      metadata || {},
      methodDescriptor_Editor_UpdateVolunteer,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.UpdateVolunteerReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.editor.Volunteer>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.updateVolunteer =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/UpdateVolunteer',
      request,
      metadata || {},
      methodDescriptor_Editor_UpdateVolunteer);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.ListVolunteersReq,
 *   !proto.org.couchers.editor.ListVolunteersRes>}
 */
const methodDescriptor_Editor_ListVolunteers = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/ListVolunteers',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.ListVolunteersReq,
  proto.org.couchers.editor.ListVolunteersRes,
  /**
   * @param {!proto.org.couchers.editor.ListVolunteersReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.editor.ListVolunteersRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.ListVolunteersReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.editor.ListVolunteersRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.editor.ListVolunteersRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.listVolunteers =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/ListVolunteers',
      request,
      metadata || {},
      methodDescriptor_Editor_ListVolunteers,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.ListVolunteersReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.editor.ListVolunteersRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.listVolunteers =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/ListVolunteers',
      request,
      metadata || {},
      methodDescriptor_Editor_ListVolunteers);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.ListPostcardsReq,
 *   !proto.org.couchers.editor.ListPostcardsRes>}
 */
const methodDescriptor_Editor_ListPostcards = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/ListPostcards',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.ListPostcardsReq,
  proto.org.couchers.editor.ListPostcardsRes,
  /**
   * @param {!proto.org.couchers.editor.ListPostcardsReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.editor.ListPostcardsRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.ListPostcardsReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.editor.ListPostcardsRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.editor.ListPostcardsRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.listPostcards =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/ListPostcards',
      request,
      metadata || {},
      methodDescriptor_Editor_ListPostcards,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.ListPostcardsReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.editor.ListPostcardsRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.listPostcards =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/ListPostcards',
      request,
      metadata || {},
      methodDescriptor_Editor_ListPostcards);
};


/**
 * @const
 * @type {!grpc.web.MethodDescriptor<
 *   !proto.org.couchers.editor.DownloadPostcardPdfReq,
 *   !proto.org.couchers.editor.DownloadPostcardPdfRes>}
 */
const methodDescriptor_Editor_DownloadPostcardPdf = new grpc.web.MethodDescriptor(
  '/org.couchers.editor.Editor/DownloadPostcardPdf',
  grpc.web.MethodType.UNARY,
  proto.org.couchers.editor.DownloadPostcardPdfReq,
  proto.org.couchers.editor.DownloadPostcardPdfRes,
  /**
   * @param {!proto.org.couchers.editor.DownloadPostcardPdfReq} request
   * @return {!Uint8Array}
   */
  function(request) {
    return request.serializeBinary();
  },
  proto.org.couchers.editor.DownloadPostcardPdfRes.deserializeBinary
);


/**
 * @param {!proto.org.couchers.editor.DownloadPostcardPdfReq} request The
 *     request proto
 * @param {?Object<string, string>} metadata User defined
 *     call metadata
 * @param {function(?grpc.web.RpcError, ?proto.org.couchers.editor.DownloadPostcardPdfRes)}
 *     callback The callback function(error, response)
 * @return {!grpc.web.ClientReadableStream<!proto.org.couchers.editor.DownloadPostcardPdfRes>|undefined}
 *     The XHR Node Readable Stream
 */
proto.org.couchers.editor.EditorClient.prototype.downloadPostcardPdf =
    function(request, metadata, callback) {
  return this.client_.rpcCall(this.hostname_ +
      '/org.couchers.editor.Editor/DownloadPostcardPdf',
      request,
      metadata || {},
      methodDescriptor_Editor_DownloadPostcardPdf,
      callback);
};


/**
 * @param {!proto.org.couchers.editor.DownloadPostcardPdfReq} request The
 *     request proto
 * @param {?Object<string, string>=} metadata User defined
 *     call metadata
 * @return {!Promise<!proto.org.couchers.editor.DownloadPostcardPdfRes>}
 *     Promise that resolves to the response
 */
proto.org.couchers.editor.EditorPromiseClient.prototype.downloadPostcardPdf =
    function(request, metadata) {
  return this.client_.unaryCall(this.hostname_ +
      '/org.couchers.editor.Editor/DownloadPostcardPdf',
      request,
      metadata || {},
      methodDescriptor_Editor_DownloadPostcardPdf);
};


module.exports = proto.org.couchers.editor;

